@@ -11,7 +11,7 @@ from tqdm.auto import tqdm
 
 from .file import RDYFile
 from .osm import OSMRegion, OSMRailwaySwitch, OSMRailwaySignal, OSMLevelCrossing
-from .osm.utils import calc_perpendicular_distance
+from .osm.utils import calc_perpendicular_distance, is_point_within_line_projection
 from .utils import GPSSeries
 from .utils.tools import generate_random_color
 
@@ -22,7 +22,7 @@ class Campaign:
     def __init__(self, name="", folder: Union[list, str] = None, recursive=True, exclude: Union[list, str] = None,
                  sync_method: str = None, strip_timezone: bool = True, cutoff: bool = True, lat_sw: float = None,
                  lon_sw: float = None, lat_ne: float = None,
-                 lon_ne: float = None, download_osm_region: bool = False, filter_osm_region: bool = True,
+                 lon_ne: float = None, download_osm_region: bool = False, filter_osm_region: bool = False,
                  railway_types: Union[list, str] = None):
         """
 
@@ -55,7 +55,7 @@ class Campaign:
             North east longitude of the campaign
         download_osm_region: bool, default: False
             If True download OSM data via the Overpass API
-        filter_osm_region: bool, default: True
+        filter_osm_region: bool, default: False
             If True removes railway elements that are not close to the GPS Tracks of the campaign
         railway_types: list or list of str
             Railway type to be downloaded from OSM, e.g., "rail", "subway", "tram" or "light_rail"
@@ -355,7 +355,7 @@ class Campaign:
                 gps_coords = f.measurements[GPSSeries]
                 track_xy = np.vstack([proj(gps_coords.lon, gps_coords.lat)]).T
 
-                for i, el in enumerate(self.osm_region.railway_elements):
+                for i, el in enumerate(tqdm(self.osm_region.railway_elements)):
                     if mask[i]:
                         continue
                     else:
@@ -363,8 +363,8 @@ class Campaign:
                             if not np.array_equal(p1, p2):
                                 el_x, el_y = proj(el.lon, el.lat)
                                 d = calc_perpendicular_distance(np.array([p1, p2]), np.array([el_x, el_y]))
-
-                                if d <= d_min:
+                                b = is_point_within_line_projection(np.array([p1, p2]), np.array([el_x, el_y]))
+                                if b and d <= d_min:
                                     mask[i] = True
                                     break
 
@@ -375,7 +375,7 @@ class Campaign:
 
     def import_files(self, paths: Union[list, str] = None, sync_method: str = None,
                      det_geo_extent: bool = True, download_osm_region: bool = False,
-                     railway_types: Union[list, str] = None):
+                     filter_osm_region: bool = False, railway_types: Union[list, str] = None):
         """ Import files into the campaign
 
         Parameters
@@ -388,6 +388,8 @@ class Campaign:
             If True, determine the geographic extent of the imported files
         download_osm_region: bool, default: False
             If True, download OSM Data via the Overpass API
+        filter_osm_region: bool, default: False
+            If True, removes railway elements that are not close to the GPS tracks
         railway_types: str or list of str
             Railway types to be downloaded via the Overpass API
         """
@@ -411,11 +413,13 @@ class Campaign:
         if download_osm_region:
             self.osm_region = OSMRegion(lat_sw=self.lat_sw, lon_sw=self.lon_sw, lat_ne=self.lat_ne, lon_ne=self.lon_ne,
                                         desired_railway_types=railway_types)
+            if filter_osm_region:
+                self.filter_osm_region()
 
     def import_folder(self, folder: Union[list, str] = None, recursive: bool = True, exclude: Union[list, str] = None,
                       sync_method: str = None, strip_timezone: bool = None, cutoff: bool = True,
                       det_geo_extent: bool = True, download_osm_region: bool = False,
-                      filter_osm_region: bool = True,
+                      filter_osm_region: bool = False,
                       railway_types: Union[list, str] = None):
         """ Imports folder(s) into the campaign
 
@@ -437,7 +441,7 @@ class Campaign:
             If True, tries to automatically determine the geographic extent of the imported files via their GPS tracks
         download_osm_region: bool, default: True
             If True, downloads OSM Data via the Overpass API
-        filter_osm_region: bool, default: True
+        filter_osm_region: bool, default: False
             If True, removes railway elements that are not close to the GPS tracks
         railway_types: str or list of str
             Railway types to be downloaded via the Overpass API
